@@ -13,7 +13,6 @@ fn test_db_store() {
 #[test]
 fn test_css_selector() {
     css_selector::run_selector();
-    css_selector::run_parser_select();
 }   
 
 #[test]
@@ -31,6 +30,5 @@ fn test_headers_json() {
 
 #[test]
 fn test_free_parse_and_store_to_csv() {
-    // css_selector::run_free_parse_and_store_to_csv();
-    css_selector::crawl_kongfz();
+    css_selector::run_free_parse_and_store_to_csv();
 }
\ No newline at end of file
